@@ -3,6 +3,6 @@
 
 void CPU::itoa()
 {
-    d_stack.top() = new String{ to_string(d_stack.top().value()) };  
+    d_stack.top() = new EString{ to_string(d_stack.top().value()) };  
                                                 // using promotion to 
 }                                               // assign Variable{ string }
