@@ -4,7 +4,7 @@
 #include <iosfwd>
 #include <string>
 
-#include <bobcat/process>
+#include "../../tmp/build/process/process"
 
 class Options;
 
